package com.gic.haoban.manage.web.controller;

import com.gic.enterprise.api.dto.PowerStoreGroupDTO;
import com.gic.enterprise.api.service.StoreGroupService;
import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.manage.api.dto.LoginDTO;
import com.gic.haoban.manage.api.dto.StoreRangeInfoDTO;
import com.gic.haoban.manage.api.dto.WxEnterpriseDTO;
import com.gic.haoban.manage.api.service.WxEnterpriseRelatedApiService;
import com.gic.haoban.manage.web.errCode.HaoBanErrCode;
import com.gic.haoban.manage.web.vo.StoreGroupVo;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@RestController
public class GicDepartmentController extends WebBaseController{
	
	private static Logger logger  = LoggerFactory.getLogger(GicDepartmentController.class);
	
	@Autowired
	private StoreGroupService storeGroupService;

	@Autowired
	private WxEnterpriseRelatedApiService wxEnterpriseRelatedApiService;
	
	@RequestMapping("gic-department-list")
	public HaobanResponse departmentList(String enterpriseId, String keyWord) {

		List<PowerStoreGroupDTO>  departmentList = storeGroupService.getStoreGroupList(enterpriseId, keyWord);
		return resultResponse(HaoBanErrCode.ERR_1,departmentList);

	}

	@RequestMapping("gic-store-group-list")
	public HaobanResponse storeGroupList(String enterpriseId, String keyWord) {
        LoginDTO loginUser = this.getLoginUser();
        String wxEnterpriseId = loginUser.getWxEnterpriseId();
		List<PowerStoreGroupDTO> departmentList = storeGroupService.getStoreGroupList(enterpriseId, keyWord);
		List<StoreRangeInfoDTO> rangeInfoDTOList = wxEnterpriseRelatedApiService.listAllBindStoreOrGroup(enterpriseId);
		Map<String, StoreRangeInfoDTO> storeRangeMap = new HashMap<>();
		if (CollectionUtils.isNotEmpty(rangeInfoDTOList)) {
			List<WxEnterpriseDTO> wxEnterpriseDTOS = wxEnterpriseRelatedApiService.listWxEnterpriseByEid(enterpriseId);
			if (CollectionUtils.isNotEmpty(wxEnterpriseDTOS)) {
				Map<String, WxEnterpriseDTO> wxEnterpriseDTOMap = wxEnterpriseDTOS.stream().collect(Collectors.toMap(WxEnterpriseDTO::getWxEnterpriseId, dto -> dto));
				storeRangeMap = rangeInfoDTOList.stream()
						.filter(dto -> (!dto.getWxEnterpriseId().equals(wxEnterpriseId))
								&& dto.getRelationType() == 1
								&& wxEnterpriseDTOMap.get(dto.getWxEnterpriseId()) != null)
						.peek(dto -> dto.setWxEnterpriseName(wxEnterpriseDTOMap.get(dto.getWxEnterpriseId()).getCorpName()))
						.collect(Collectors.toMap(StoreRangeInfoDTO::getRelationId, dto -> dto));
			}
		}
		Map<String, StoreRangeInfoDTO> finalStoreRangeMap = storeRangeMap;
		List<StoreGroupVo> ret = departmentList.stream().map(dto -> {
			StoreRangeInfoDTO mid = finalStoreRangeMap.get(dto.getStoreGroupId());
			StoreGroupVo storeGroupVo = new StoreGroupVo();
			storeGroupVo.setRelationId(dto.getStoreGroupId());
			storeGroupVo.setParentRelationId(dto.getParentGroupId());
			if (mid != null) {
				storeGroupVo.setIsBind(1);
				storeGroupVo.setWxEnterpriseId(mid.getWxEnterpriseId());
				storeGroupVo.setWxEnterpriseName(mid.getWxEnterpriseName());
			}
			storeGroupVo.setRelationType(1);
			storeGroupVo.setRelationName(dto.getStoreGroupName());
			return storeGroupVo;
		}).collect(Collectors.toList());
		return resultResponse(HaoBanErrCode.ERR_1, ret);

	}

}
